USE asterisk;
/*
 * System Definition
 *
 * (C) Copyright 2017-2021, Bogen Communications, Inc. All rights reserved.
 *
 * This table represents a system, otherwise known as a facility
 * A row in the system table exists for each facility being managed.
 * In the actual implementation, a Nyquist server only has one facility,
 * thus one row.
 *
 * system.id          - is the facility number
 *  .name             - is the facility name (for display)
 *  .day_start        - HH:MM representing start of day
 *  .night_start      - HH:MM representing start of night 
 *  .ip_multicast_rtp - IP Adress for Multicast RTP
 *  .disable_preannounce_tone - TRUE will disable paging preannounce tone
 *  .default_system_password  - When a user adds a new station, this is the
 *                              default password for the password field.
 *  .dialing_length   - Specifies the number of digits required to dial
 *                      within the system.
 *  .emergency_tone   - Defines pre-announce tone played when an Emergency
 *                      All-Call is made.
 *  .default_codecs_allowed - Default value for ps_endpoints.allow
 *                            which is the list of Media Codecs allowed.
 *
 *  .valid_codec_list	- A semi-colon seperated list of codecs that are
 *			  selectable in the default_codecs_allowed drop down
 *
 *  .all_call_tone    - Defines the pre-announce tone played when an All-Call 
 *                      is made.
 *
 *  .privacy_beep	- TRUE will enable privacy beep
 *
 *  .admin_queue_timeout - Timeout for admin phone queues.
 *
 *  .nightring_zonelist - List of Zones to ring (2500 allows for 500 Zones).
 *
 *  .nightring_stationlist - List of stations from zones (12000 allows for 1000 stations).
 *  .trunk_priority - Trunk type to use first (trunk_priority_enum.id)
 *  .bump_on_emergency - If true, bump existing admin call in favor of incoming
 *                       emergency call to admin.
 *  .bump_on_911 - If true, bump existing trunk call in favor of outgoing
 *                 call to 911.
 *  .backup_dir - Directory used to store system backups.
 *
 */
DROP TABLE IF EXISTS system;
SELECT 'Creating system table' AS ' ';
CREATE TABLE system (
	id			int(5) NOT NULL,
	name			varchar(40),
	day_start		time NOT NULL,
	night_start		time NOT NULL,
	ip_multicast_rtp	int unsigned NULL,
	ip_multicast_port	int(10) NULL DEFAULT '6061',
	eallcall_volume		int(3) NOT NULL DEFAULT '0',
	allcall_multicast_ip	int unsigned NULL,
	allcall_multicast_port	int(10) NULL DEFAULT '6062',
	allcall_volume		int(3) NOT NULL DEFAULT '-3',
	audiodist_multicast_ip	int unsigned NULL,
	audiodist_multicast_port int(10) NULL DEFAULT '6060',
	audiodist_volume	int(3) NOT NULL DEFAULT '-24',
	disable_preannounce_tone boolean NOT NULL DEFAULT 0,
	default_station_password varchar(20) NOT NULL DEFAULT 'bogen',
	dialing_length		tinyint NOT NULL DEFAULT '3',
	emergency_tone		varchar(128) NOT NULL DEFAULT '/var/lib/asterisk/sounds/beep_sine_500hz-1',
	default_codecs_allowed	varchar(200) NOT NULL DEFAULT 'g722;ulaw;speex',
	valid_codec_list	varchar(200) NOT NULL DEFAULT 'all;adpcm;alaw;g719;g722;g723;g726;g726aal2;g729;gsm;opus;siren7;siren14;slin;speex;ulaw',
	all_call_tone		varchar(128) NOT NULL DEFAULT '/var/lib/asterisk/sounds/burst',
	privacy_beep		boolean NOT NULL DEFAULT 0,
	intercom_tone		varchar(128) NOT NULL DEFAULT '/var/lib/asterisk/sounds/burst',
	default_volume		int(3) NOT NULL DEFAULT '-6',
	ip_ntp_server		varchar(100) NOT NULL DEFAULT '24.56.178.140',
	admin_queue_timeout	int(3) NOT NULL DEFAULT 30,
	time_zone		varchar(100) NOT NULL DEFAULT 'America/New_York',
	nightring_enabled	boolean NOT NULL DEFAULT 0,
	nightring_admin_extension varchar(40) DEFAULT '',
	nightring_admin_group	varchar(128) DEFAULT '',
	nightring_zonelist	varchar(2500) DEFAULT '',
	nightring_allstations	boolean NOT NULL DEFAULT 0,
	nightring_stationlist	varchar(12000) DEFAULT '',
	dhcp_override		boolean NOT NULL DEFAULT 0,
	server_ipaddr		int unsigned NULL,
	parking_lot		varchar(20),
	record_monitoring	boolean NOT NULL DEFAULT 0,
	emergency_link		varchar(40) NOT NULL DEFAULT '999',
	max_restricted_digits	tinyint NOT NULL DEFAULT '10',
	disa_password		varchar(4) NOT NULL DEFAULT '6459',
	security_disa_password	varchar(4) NOT NULL DEFAULT '6459',
	call_log_length		int(3) NOT NULL DEFAULT '30',
	trunk_priority		int(2) NOT NULL DEFAULT '1',
	bump_on_emergency	boolean NOT NULL DEFAULT 1,
	bump_on_911		boolean NOT NULL DEFAULT 1,
	auth_code		varchar(4) NOT NULL DEFAULT '0000',
	call_assurance_audio	varchar(128) NOT NULL DEFAULT 'call-placed',
	remote_facility_cos	int NOT NULL DEFAULT '1',
	neighbor_secret		varchar(128) NOT NULL DEFAULT 'BogenSrvNyq1',
	rtpstart		varchar(10) NOT NULL DEFAULT '10000',
	rtpend			varchar(10) NOT NULL DEFAULT '20000',
	rtpchecksums		boolean NOT NULL DEFAULT 0,
	icesupport		boolean NOT NULL DEFAULT 1,
	stunaddr		varchar(80) DEFAULT '',
	turnaddr		varchar(80) DEFAULT '',
	turnusername		varchar(80) DEFAULT '',
	turnpassword		varchar(80) DEFAULT '',
	vlan_enabled		boolean NOT NULL DEFAULT 0,
	vlan_id			int(4) DEFAULT '0',
	priority_802_1p		int(1) DEFAULT '0',
	retention_recordings	int(5) NOT NULL DEFAULT '365',
	backup_retention_system		int(5) NOT NULL DEFAULT '365',
	backup_retention_recordings	int(5) NOT NULL DEFAULT '365',
	backup_retention_voicemail	int(5) NOT NULL DEFAULT '365',
	system_password		varchar(4) NOT NULL DEFAULT '1234',
	appliance_ntp_source	enum('nyquist','dhcp','ntpserver') DEFAULT 'nyquist',
	ans_multicast_ip	int unsigned NULL,
	ans_multicast_port	int(10) NULL,
	teamviewer_enabled	boolean NOT NULL DEFAULT 0,
	enable_routines_api	boolean NOT NULL DEFAULT 0,
	allow_local_eallcall_page_interrupt	boolean NOT NULL DEFAULT 0,
	allow_multisite_eallcall_page_interrupt	boolean NOT NULL DEFAULT 0,
	pin_multisite_emerg_all_call	varchar(4) DEFAULT '',
	pin_multisite_all_call		varchar(4) DEFAULT '',
	pin_facility_page		varchar(4) DEFAULT '',
	pin_emerg_all_call		varchar(4) DEFAULT '',
	pin_all_call			varchar(4) DEFAULT '',
	pin_emerg_announcement		varchar(4) DEFAULT '',
	pin_announcement		varchar(4) DEFAULT '',
	pin_facility_emerg_announcement	varchar(4) DEFAULT '',
	pin_facility_announcement	varchar(4) DEFAULT '',
	pin_zone_page			varchar(4) DEFAULT '',
	pin_alarm			varchar(4) DEFAULT '',
	pin_tone			varchar(4) DEFAULT '',
	disable_eallcall_intercom_when_audiodisabled boolean NOT NULL DEFAULT 0,
	zone_control_password		varchar(80) DEFAULT 'bogen',
	routine_api_key			varchar(50) DEFAULT '',
	include_ip_addresses_in_ssl_san_list	varchar(255) NOT NULL DEFAULT '',
	remote_calendar_control		enum('disabled','allow_facilities','allow_access_list') NOT NULL DEFAULT 'disabled',
	calendar_control_access_list	varchar(4095) NOT NULL DEFAULT '',
	backup_tone			varchar(128) NOT NULL DEFAULT '/var/lib/asterisk/sounds/beep_sine_500hz-5',
	cri_enabled			boolean NOT NULL DEFAULT 0,
	cri_expiration			enum('0','1','2','3','4','5','6','7','8','9','10','11','12','13','14','15','16','17','18','19','20','21','22','23','24') NOT NULL DEfAULT '12',
	weather_api_key			varchar(128) NOT NULL DEFAULT '',
	weather_zipcode			varchar(10) NOT NULL DEFAULT '',
PRIMARY KEY (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
